@@ -5,11 +5,11 @@ package MouseyComposer;
 use Mouse;
 extends 'MouseyClean';
 with 'MouseyRole';
-use Scalar::Util 'weaken';
+use File::Spec::Functions 'catfile';
 use namespace::autoclean;
 
 sub child_stuff {}
 
 use constant CAN => [ qw(stuff role_stuff child_stuff meta) ];
-use constant CANT => [ qw(has with refaddr reftype weaken)];
+use constant CANT => [ qw(has with catdir devnull catfile)];
 1;
